@@ -28,6 +28,27 @@ def test_oifs_global_mean_year_mean_timeseries_working(tmp_path):
     )
 
 
+def test_oifs_timeseries_compare_grids(tmp_path):
+    init = {
+        "src": ["./tests/testdata/regular_grid_tas.nc"],
+        "dst": str(tmp_path / "test_reg.nc"),
+        "varname": "tas",
+    }
+    atmo_ts = OifsGlobalMeanYearMeanTimeseries(init)
+    atmo_ts.run(init)
+    cube_reg = iris.load_cube(init["dst"])
+
+    init = {
+        "src": ["./tests/testdata/reduced_grid_tas.nc"],
+        "dst": str(tmp_path / "test_red.nc"),
+        "varname": "tas",
+    }
+    atmo_ts = OifsGlobalMeanYearMeanTimeseries(init)
+    atmo_ts.run(init)
+    cube_red = iris.load_cube(init["dst"])
+    assert abs(cube_red.data - cube_reg.data) < 1e-3
+
+
 def test_oifs_global_mean_year_mean_timeseries_wrong_varname(tmp_path):
     init = {
         "src": ["./tests/testdata/TES1_atm_1m_1990_2t.nc"],
